Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1640)

Unified Diff: ash/wm/tablet_mode/tablet_mode_window_manager.h

Issue 2906803002: Rename MaximizeMode to TabletMode (Closed)
Patch Set: updated filter Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/wm/tablet_mode/tablet_mode_window_manager.h
diff --git a/ash/wm/maximize_mode/maximize_mode_window_manager.h b/ash/wm/tablet_mode/tablet_mode_window_manager.h
similarity index 84%
rename from ash/wm/maximize_mode/maximize_mode_window_manager.h
rename to ash/wm/tablet_mode/tablet_mode_window_manager.h
index fbdedccf7d17d1ee97e95d3cd3399bbcd26b7ce8..bdf552173750bf8fd71925ec8309bcdf6c81d9cb 100644
--- a/ash/wm/maximize_mode/maximize_mode_window_manager.h
+++ b/ash/wm/tablet_mode/tablet_mode_window_manager.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef ASH_WM_MAXIMIZE_MODE_MAXIMIZE_MODE_WINDOW_MANAGER_H_
-#define ASH_WM_MAXIMIZE_MODE_MAXIMIZE_MODE_WINDOW_MANAGER_H_
+#ifndef ASH_WM_TABLET_MODE_TABLET_MODE_WINDOW_MANAGER_H_
+#define ASH_WM_TABLET_MODE_TABLET_MODE_WINDOW_MANAGER_H_
#include <stdint.h>
@@ -22,25 +22,25 @@ class Window;
}
namespace ash {
-class MaximizeModeController;
-class MaximizeModeWindowState;
+class TabletModeController;
+class TabletModeWindowState;
namespace wm {
-class MaximizeModeEventHandler;
+class TabletModeEventHandler;
}
// A window manager which - when created - will force all windows into maximized
// mode. Exception are panels and windows which cannot be maximized.
// Windows which cannot be maximized / resized are centered with a layer placed
// behind the window so that no other windows are visible and/or obscured.
// With the destruction of the manager all windows will be restored to their
// original state.
-class ASH_EXPORT MaximizeModeWindowManager : public aura::WindowObserver,
- public display::DisplayObserver,
- public ShellObserver {
+class ASH_EXPORT TabletModeWindowManager : public aura::WindowObserver,
+ public display::DisplayObserver,
+ public ShellObserver {
public:
// This should only be deleted by the creator (ash::Shell).
- ~MaximizeModeWindowManager() override;
+ ~TabletModeWindowManager() override;
// Returns the number of maximized & tracked windows by this manager.
int GetNumberOfManagedWindows();
@@ -79,13 +79,13 @@ class ASH_EXPORT MaximizeModeWindowManager : public aura::WindowObserver,
void SetIgnoreWmEventsForExit();
protected:
- friend class MaximizeModeController;
+ friend class TabletModeController;
// The object should only be created by the ash::Shell.
- MaximizeModeWindowManager();
+ TabletModeWindowManager();
private:
- using WindowToState = std::map<aura::Window*, MaximizeModeWindowState*>;
+ using WindowToState = std::map<aura::Window*, TabletModeWindowState*>;
// Maximize all windows and restore their current state.
void MaximizeAllWindows();
@@ -135,11 +135,11 @@ class ASH_EXPORT MaximizeModeWindowManager : public aura::WindowObserver,
// Windows added to the container, but not yet shown.
std::unordered_set<aura::Window*> added_windows_;
- std::unique_ptr<wm::MaximizeModeEventHandler> event_handler_;
+ std::unique_ptr<wm::TabletModeEventHandler> event_handler_;
- DISALLOW_COPY_AND_ASSIGN(MaximizeModeWindowManager);
+ DISALLOW_COPY_AND_ASSIGN(TabletModeWindowManager);
};
} // namespace ash
-#endif // ASH_WM_MAXIMIZE_MODE_MAXIMIZE_MODE_WINDOW_MANAGER_H_
+#endif // ASH_WM_TABLET_MODE_TABLET_MODE_WINDOW_MANAGER_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -22,25 +22,25 @@ class Window;
}
-// A window manager which - when created - will force all windows into maximized
+// A window manager which - when created - will force all windows into tablet
// mode. Exception are panels and windows which cannot be maximized.
// Windows which cannot be maximized / resized are centered with a layer placed